Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/dynapydantic/__init__.py | (no class) | 4 | 0 | 0 | 0 | 0 | 100%
src/dynapydantic/exceptions.py | Error | 0 | 0 | 0 | 0 | 0 | 100%
src/dynapydantic/exceptions.py | RegistrationError | 0 | 0 | 0 | 0 | 0 | 100%
src/dynapydantic/exceptions.py | AmbiguousDiscriminatorValueError | 0 | 0 | 0 | 0 | 0 | 100%
src/dynapydantic/exceptions.py | ConfigurationError | 0 | 0 | 0 | 0 | 0 | 100%
src/dynapydantic/exceptions.py | (no class) | 4 | 0 | 0 | 0 | 0 | 100%
src/dynapydantic/subclass_tracking_model.py | SubclassTrackingModel | 27 | 0 | 0 | 10 | 0 | 100%
src/dynapydantic/subclass_tracking_model.py | (no class) | 10 | 0 | 0 | 0 | 0 | 100%
src/dynapydantic/tracking_group.py | TrackingGroup | 41 | 0 | 0 | 22 | 0 | 100%
src/dynapydantic/tracking_group.py | (no class) | 20 | 0 | 0 | 0 | 0 | 100%
Total |  | 106 | 0 | 0 | 32 | 0 | 100%

No items found using the specified filter.